#########
Model API
#########

.. autoclass:: datarobot.models.Model
   :members:
   :exclude-members: from_server_data

##############
PrimeModel API
##############

.. autoclass:: datarobot.models.PrimeModel
   :members:
